@@ -30,7 +30,7 @@ import org.apache.tools.ant.Project;
  * by the mod_jk status (1.2.13) application.
  * 
  * @author Peter Rossbach
- * @version $Revision: 485242 $
+ * @version $Revision: 502062 $
  * @since 5.5.10
  */
 public class JkStatusTask extends BaseRedirectorHelperTask {
@@ -425,6 +425,10 @@ public class JkStatusTask extends BaseRedirectorHelperTask {
                 Integer.toString(balancer.getMember_count()));
         getProject().setNewProperty(prefix + ".max_busy",
                 Integer.toString(balancer.getMax_busy()));
+        getProject().setNewProperty(prefix + ".time_to_maintenance_min",
+                Integer.toString(balancer.getTime_to_maintenance_min()));
+        getProject().setNewProperty(prefix + ".time_to_maintenance_max",
+                Integer.toString(balancer.getTime_to_maintenance_max()));
         getProject().setNewProperty(prefix + ".lock",
                 balancer.getLock());
  
@@ -469,9 +473,15 @@ public class JkStatusTask extends BaseRedirectorHelperTask {
         if(balancer.getMember_count() >=0) {
         	createProperty(balancer, balancerIndex, "member_count");
         }
-        if(balancer.getMember_count() >=0) {
+        if(balancer.getMap_count() >=0) {
         	createProperty(balancer, balancerIndex, "map_count");
         }
+        if(balancer.getTime_to_maintenance_min() >=0) {
+        	createProperty(balancer, balancerIndex, "time_to_maintenance_min");
+        }
+        if(balancer.getTime_to_maintenance_max() >=0) {
+        	createProperty(balancer, balancerIndex, "time_to_maintenance_max");
+        }
    }
 
     /**
@@ -622,6 +632,17 @@ public class JkStatusTask extends BaseRedirectorHelperTask {
             currentProject.setNewProperty(prefix + ".time_to_recover",
                     Integer.toString(member.getTime_to_recover()));
         }
+        if(member.getTime_to_recover_min() >= 0) {
+            currentProject.setNewProperty(prefix + ".time_to_recover_min",
+                    Integer.toString(member.getTime_to_recover_min()));
+        }
+        if(member.getTime_to_recover_max() >= 0) {
+            currentProject.setNewProperty(prefix + ".time_to_recover_max",
+                    Integer.toString(member.getTime_to_recover_max()));
+            currentProject.setNewProperty(prefix + ".time_to_recover",
+                    (Integer.toString((member.getTime_to_recover_min()
+                            + member.getTime_to_recover_max()) / 2)));
+        }
             
     }
 
@@ -708,4 +729,4 @@ public class JkStatusTask extends BaseRedirectorHelperTask {
         }
     }
 
-}
\ No newline at end of file
+}
