@@ -19,7 +19,7 @@
  * Description: NT System service for Tomcat                       *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  *              Dave Oxley <Dave@JungleMoss.com>                           *
- * Version:     $Revision: 479311 $                                           *
+ * Version:     $Revision: 500880 $                                           *
  ***************************************************************************/
 
 #include "jk_global.h"
@@ -956,7 +956,7 @@ static int exec_cmd(const char *name, HANDLE *hTomcat, char *cmdLine)
             jk_map_t *init_map;
             
             if(jk_map_alloc(&init_map)) {
-                if(jk_map_read_properties(init_map, prp_file, NULL, NULL)) {
+                if(jk_map_read_properties(init_map, prp_file, NULL, 1, NULL)) {
                     jk_tomcat_startup_data_t data;
                     jk_pool_t p;
                     jk_pool_atom_t buf[HUGE_POOL_SIZE];
